Python base modules of Frank Brehm
==================================

These are Python modules for common used objects, error classes and functions.

Author: Frank Brehm (<frank@brehm-online.com>)


Liste der VMWare-OS-Identifier:
-------------------------------

https://www.vmware.com/support/orchestrator/doc/vro-vsphere65-api/html/VcVirtualMachineGuestOsIdentifier.html

Liste ce VMWare Virtual Hardware Versions:
------------------------------------------

https://kb.vmware.com/s/article/1003746
